@@ -1,16 +1,9 @@
 /*
- *
- * Copyright (C) 2005-2009 Sebastian Trueg <trueg@k3b.org>
- *
- * This file is part of the K3b project.
- * Copyright (C) 1998-2009 Sebastian Trueg <trueg@k3b.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- * See the file "COPYING" for the exact licensing terms.
- */
+    SPDX-FileCopyrightText: 2005-2009 Sebastian Trueg <trueg@k3b.org>
+    SPDX-FileCopyrightText: 1998-2009 Sebastian Trueg <trueg@k3b.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "k3bmediaselectiondialog.h"
 #include "k3bmediaselectioncombobox.h"
@@ -117,4 +110,4 @@ K3b::Device::Device* K3b::MediaSelectionDialog::selectMedium( Device::MediaTypes
     }
 }
 
-
+#include "moc_k3bmediaselectiondialog.cpp"
